// Based on original classic Quaternion bundled with Fragmentarium
// Modifications added by Patryk Kizny / kizny.com
// 2015/06/15
//  - Added box folding
// - Added Sphere Folding
// - Added Volume culling
// - Added general fractal repositioning

#info 4D Quaternion Julia DE + Box Folding + Sphere Folding

#define USE_IQ_CLOUDS
#define USE_IQ_CLOUDS_MULTILAYER // Multilayer Clouds by PK

#define KN_VOLUMETRIC
#define providesInit

#define USE_EIFFIE_SHADOW
#define PERFECT_DE

#include "DE-Kn2-PK.1.0.3.frag"
//#include "DE-Kn2.frag"

#include "MathUtils.frag"
//#include "Presets-Camera.frag"
//#include "Presets-Detail.frag"
//#include "Presets-Lighting_DE-Kn2-Pk-1.0.3.frag"
//#include "Presets-JuliaQT.frag"

#group Fractal Reposition
// Added global transformations to the return fractal
// sometimes its easier to rotate the thing instead of moving the camera around

uniform float fRotX; slider[-180.00,0,180]
uniform float fRotY; slider[-180.00,0,180]
uniform float fRotZ; slider[-180.00,0,180]

uniform float fScaleX; slider[0.001,1,10]
uniform float fScaleY; slider[0.001,1,10]
uniform float fScaleZ; slider[0.001,1,10]

uniform float fTwist; slider[-2,0,2]

uniform float fX; slider[-10,0,10]
uniform float fY; slider[-10,0,10]
uniform float fZ; slider[-10,0,10]

#group Fractal Slicer
// Allows for slicing the fractal and rendering only a box-limited volume
// Box may be sclaed/rotated/translated

uniform bool clipToBox; checkbox[false]
uniform bool showClippingBox; checkbox[false]

uniform vec3 boxRotVector; slider[(0,0,1),(0,0,1),(0,0,1)]
uniform float boxRotAngle; slider[0.00,0,180]

uniform float boxW; slider[0,5,10]
uniform float boxH; slider[0,5,10]
uniform float boxD; slider[0,1,10]

uniform float boxX; slider[-10,0,10]
uniform float boxY; slider[-10,0,10]
uniform float boxZ; slider[-10,0,10]

#group box Folding
// Added box folding by Patryk Kizny
// Sphere folding does not seem to work for this fractal

uniform bool foldBoxSeparateAxes; checkbox[false]
uniform int foldBoxStartIt; slider[0,16,256]
uniform int foldBoxIts; slider[0,1,16]

uniform vec3 Trans; slider[(-5,-5,-5),(0.5,0.5,0.5),(5,5,5)]

uniform float foldingLimitX; slider[-5,0,5]
uniform float foldingValueX; slider[-5,2,5]

uniform float foldingLimitY; slider[-5,0,5]
uniform float foldingValueY; slider[-5,2,5]

uniform float foldingLimitZ; slider[-5,0,5]
uniform float foldingValueZ; slider[-5,2,5]

uniform vec3 rotVector; slider[(0,0,0),(1,1,1),(1,1,1)]
uniform float rotAngle; slider[0.00,0,180]

#group sphere Folding + Other

uniform int foldSphereStartIt; slider[0,16,256]
uniform int foldSphereIts; slider[0,1,16]

uniform float posW; slider[-1,0,1]
uniform float Scale;  slider[-3.0,1,3.0]
uniform float MinRad2;  slider[0,0.25,2.0]
uniform vec3 Julia; slider[(-5,-5,-5),(0,0,0),(5,5,5)]

#group 4D Quaternion Julia

// Number of fractal iterations.
uniform int QTIterations;  slider[0,16,100]
// Breakout distance
uniform float QTThreshold; slider[0,10,100]
// Quaterion Constant
uniform vec4 QTC; slider[(-1,-1,-1,-1),(0.18,0.88,0.24,0.16),(1,1,1,1)]


// ---------------------------------------- Init -------------------------------------------


// MBox
mat3 rot;

void init() {
	rot = rotationMatrix3(normalize(rotVector),rotAngle);
}

float absScalem1 = abs(Scale - 1.0);
float AbsScaleRaisedTo1mIters = pow(abs(Scale), float(1-QTIterations));
vec4 scale = vec4(Scale, Scale, Scale, abs(Scale)) / MinRad2;



// ---------------------------------------- Box bounds & extras

float DEBox( vec3 p, vec3 box)
{
	vec3 boxd = abs(p) -  box;
	return min(max(boxd.x,max(boxd.y,boxd.z)),0.0) + length(max(boxd,0.0));
	
}

vec3 opTranslate(vec3 p, vec3 d){
	mat4 m = translate(d);
	vec3 p1 = inverse(m)*vec4(p.x, p.y, p.z,1);
	return p1;
}

vec3 opRotate(vec3 p, vec3 v, float angle){
	mat4 m = rotationMatrix(normalize(v),angle);
	vec3 p1 = inverse(m)*vec4(p.x, p.y, p.z,1);
	return p1;
}

vec3 opTwist( vec3 p, float tw)
{
	float c = cos(tw*p.y);
	float s = sin(tw*p.y);
	mat2  m = mat2(c,-s,s,c);
	vec3  q = vec3(p.xz*m,p.y);
	return q;
}

vec3 opScale( vec3 p, float s)
{
	return (p / s);
}

vec3 opScale3( vec3 p, vec3 s)
{
	return (p / s);
}

// ---------------------------------------- Quaternion Modified -------------------------------------------


// The DE implementation here is based on the implementation by Subblue:
//  http://www.subblue.com/blog/2009/9/20/quaternion_julia
// which in turn is based on a CG shader by Keenan Crane.
// My implementation here is very compressed, so take a look at Subblue's above for a much clearer implementation.

// The inline expanded quaterion multiplications make this DE
// look much worse than it actually is.

float DEQT(vec3 pos) {
	
	// QT original
	//	vec4 p = vec4(pos, 0.0);
	// MB original
	//	vec4 p = vec4(pos,1);
	// Interactive
	vec4 p = vec4(pos, posW);
	vec4 dp = vec4(1.0, 0.0,0.0,0.0);
	
	for (int i = 0; i <QTIterations; i++){
		
		// Quaternion interations
		dp = 2.0* vec4(p.x*dp.x-dot(p.yzw, dp.yzw), p.x*dp.yzw+dp.x*p.yzw+cross(p.yzw, dp.yzw));
		p = vec4(p.x*p.x-dot(p.yzw, p.yzw), vec3(2.0*p.x*p.yzw)) + QTC;
		
		// My Extras
		//rotation
		p.xyz *= rot;
		
		// other folding
		//p.xyz =  abs(p.xyz) + Trans;
		
		//  Box Folding
		if ( i >= foldBoxStartIt && i < foldBoxStartIt + foldBoxIts){
			
			if (foldBoxSeparateAxes){
				//  Box Folding (v1) - separate axes
				//p.x = clamp(p.x, -foldingLimitX, foldingLimitX)*foldingValueX - p.x;
				//p.y = clamp(p.y, -foldingLimitY, foldingLimitY)*foldingValueY - p.y ;
				//p.z = clamp(p.z, -foldingLimitZ, foldingLimitZ)*foldingValueZ - p.z;
				
				//  Box Folding (v2) - separate axes + offset
				p.x = clamp(p.x, -foldingLimitX, foldingLimitX) * foldingValueX - p.x + Trans.x;
				p.y = clamp(p.y, -foldingLimitY, foldingLimitY) * foldingValueY - p.y + Trans.y;
				p.z = clamp(p.z, -foldingLimitZ, foldingLimitZ) * foldingValueZ - p.z + Trans.z;
				
			} else {
				// Box Folding (v0)
				p.xyz = clamp(p.xyz, -foldingLimitX, foldingLimitX)*foldingValueX- p.xyz;
			}
		}
		// Sphere folding & scale
		if ( i >= foldSphereStartIt && i < foldSphereStartIt + foldSphereIts){
			float r2 = dot(p.xyz, p.xyz);
			p *= clamp(max(MinRad2/r2, MinRad2), 0.0, 1.0);
			p = p*scale + vec4(Julia,0);
		}
		
		float p2 = dot(p,p);
		orbitTrap = min(orbitTrap, abs(vec4(p.xyz,p2)));
		if (p2 > QTThreshold) break;
		
	}
	
	//QT
	float r = length(p);
	return  0.5 * r * log(r) / length(dp);	
}

// ----------------------------------------Main -------------------------------------------

float DE(vec3 z) {
	
	// get slice volume
	vec3 z1 = opRotate(z, boxRotVector, boxRotAngle);
	vec3 z2 = opTranslate(z1, vec3(boxX,boxY,boxZ));
	float deBox =  DEBox(z2, vec3( boxW, boxH, boxD));
	
	// apply fractal transformations
	z = opScale3(z, vec3(fScaleX,fScaleY,fScaleZ));
	z = opTranslate(z,vec3(fX,fY,fZ));

	z = opRotate(z,vec3(1,0,0), fRotX);
	z = opRotate(z,vec3(0,1,0), fRotY);
	z = opRotate(z,vec3(0,0,1), fRotZ);

	z = opTwist(z,fTwist);
	
	//  Instantiate
	//	z.x = mod(z.x,spacingXY)+vec2(offsX); //spacingXY
	
	//get fractal
	float deQT =  DEQT(z);
	
	// return plain fractal
	float DE = deQT;
	
	// clip to volume
	if (clipToBox){
		DE =max(deQT, deBox);
	}
	// disply cutting volume
	if (showClippingBox) {
		DE = min(deQT, deBox);
	}
	
	// return DE
	return DE;
	
}


// ---------------------------------------- Presets -------------------------------------------


#preset  BetweenTheClouds-Fog-Clouds-Volumetric
FOV = 1.5
UseTrueFOV = true
TrueFOV = 75
UseFocalLength = false
FocalLength = 9.41347
FilmGate = 36
Eye = 0.3,-1.5562,1.37211
Ey_ = 0,-4.5,6.61604e-12
Target = 0.3,0.0535112,-0.1275
Targe_ = 0,-3.5,0.75
FocalPlane = 2
Aperture = 0
InFocusAWidth = 0.5
ApertureNbrSides = 5
ApertureRot = 0
ApStarShaped = false
Gamma = 2
ToneMapping = 3
Exposure = 1
Brightness = 1
Contrast = 1
Saturation = 1
GaussianWeight = 1
AntiAliasScale = 2
Bloom = false
BloomIntensity = 0.25
BloomPow = 2
BloomTaps = 4
Detail = -3.5
DetailAO = -0.5
AutoFocus = true
FudgeFactor = 0.95
MaxRaySteps = 512
MaxDistance = 15
MaxRayStepsDiv = 10
Dither = 0.95
NormalBackStep = 5
AO = 0.0901961,0.4,0.494118,1
AoCorrect = 0
Specular = 0.4
SpecularExp = 8
SpecularMax = 16
SunLight = 1,0.976471,0.705882,1
SunDir = -0.5,-0.15
QualityShadows = true Locked
DebugSun = false
CamLight = 1,1,1,1
CamLightMin = 0.1
Glow = 1,1,1,0
GlowMax = 0
Fog = 0
FogExp = 0
Reflection = 0,0,0
ReflectionsNumber = 0
SpotGlow = true Locked
SpotLight = 1,1,1,2
SpotLightPos = 0,0,2.5
LightSize = 0.05
LightFallOff = 0.2
LightGlowRad = 0.5
LightGlowExp = 1
HardShadow = 1
ShadowSoft = 15
BaseColor = 0.443137,0.443137,0.443137
OrbitStrength = 0.5
X = 0,0.666667,0.498039,0.5
Y = 0,0.666667,1,0.5
Z = 1,0,0.498039,0.5
R = 0.32549,0.513725,0.670588,0.5
BackgroundColor = 0.211765,0.321569,0.619608
GradientBackground = 0.2
CycleColors = false
Cycles = 1
EnableFloor = false Locked
FloorNormal = 0,0,1 Locked
FloorHeight = -1.1
FloorColor = 1,1,1
HF_Fallof = 2
HF_Const = 0
HF_Intensity = 1
HF_Dir = 0,0,1
HF_Offset = -0.3
HF_Color = 0.137255,0.168627,0.27451,1
HF_Scatter = 10
HF_Anisotropy = 0,0,0
HF_FogIter = 2
HF_CastShadow = true
HCloudScale = 1
HCloudFlatness = 0.7
HCloudTops = 4
HCloudBase = 1
HCloudDensity = 0.3
HCloudRoughness = 0.5
HCloudContrast = 10
HCloudColor = 1,1,1
HCloudWindDir = 0.5,0.5,0
HCloudWindSpeed = 1
mtime = -180
CloudScale = 0.72528
CloudFlatness = 0
CloudTops = 1
CloudBase = -4
CloudDensity = 0.7
CloudRoughness = 1.7
CloudContrast = 5
CloudColor = 0.501961,0.501961,0.501961
SunLightColor = 1,1,1
WindDir = 0,1,0
WindSpeed = 1
fRotX = 90
fRotY = 0
fRotZ = 90
fScaleX = 3
fScaleY = 3
fScaleZ = 3
fTwist = 0
fX = 0
fY = 0
fZ = -0.65
clipToBox = false Locked
showClippingBox = false Locked
boxRotAngle = 0
boxW = 5
boxH = 5
boxD = 0.25
boxX = 0
boxY = 0
boxZ = 0.4102
foldBoxSeparateAxes = false Locked
foldBoxStartIt = 256 Locked
foldBoxIts = 0 Locked
Trans = 1.584,0.5096,-0.3719
foldingLimitX = 0
foldingValueX = 2
foldingLimitY = 0
foldingValueY = 0
foldingLimitZ = 0
foldingValueZ = 0
rotVector = 0,1,0
rotAngle = 0
foldSphereStartIt = 256 Locked
foldSphereIts = 3 Locked
posW = 0
Scale = 0.74178
MinRad2 = 1.13636
Julia = 0,0,0
QTIterations = 12
QTThreshold = 16
QTC = 0.1,0.95,0.1,0
Up = -6.72315e-10,0.681641,0.731687
boxRotVector = 0,0,1
#endpreset


#preset BetweenTheClouds-Fog-Clouds-Volumetric-Sliced
FOV = 1.5
UseTrueFOV = true
TrueFOV = 75
UseFocalLength = false
FocalLength = 9.41347
FilmGate = 36
Eye = 0.3,-1.5562,1.37211
Ey_ = 0,-4.5,6.61604e-12
Target = 0.3,0.0535112,-0.1275
Targe_ = 0,-3.5,0.75
FocalPlane = 2
Aperture = 0
InFocusAWidth = 0.5
ApertureNbrSides = 5
ApertureRot = 0
ApStarShaped = false
Gamma = 2
ToneMapping = 3
Exposure = 1
Brightness = 1
Contrast = 1
Saturation = 1
GaussianWeight = 1
AntiAliasScale = 2
Bloom = false
BloomIntensity = 0.25
BloomPow = 2
BloomTaps = 4
Detail = -3.5
DetailAO = -0.5
AutoFocus = true
FudgeFactor = 0.95
MaxRaySteps = 512
MaxDistance = 15
MaxRayStepsDiv = 10
Dither = 0.95
NormalBackStep = 5
AO = 0.0901961,0.4,0.494118,1
AoCorrect = 0
Specular = 0.4
SpecularExp = 8
SpecularMax = 16
SunLight = 1,0.976471,0.705882,1
SunDir = -0.5,-0.15
QualityShadows = true Locked
DebugSun = false
CamLight = 1,1,1,1
CamLightMin = 0.1
Glow = 1,1,1,0
GlowMax = 0
Fog = 0
FogExp = 0
Reflection = 0,0,0
ReflectionsNumber = 0
SpotGlow = true Locked
SpotLight = 1,1,1,2
SpotLightPos = 0,0,2.5
LightSize = 0.05
LightFallOff = 0.2
LightGlowRad = 0.5
LightGlowExp = 1
HardShadow = 1
ShadowSoft = 15
BaseColor = 0.443137,0.443137,0.443137
OrbitStrength = 0.5
X = 0,0.666667,0.498039,0.5
Y = 0,0.666667,1,0.5
Z = 1,0,0.498039,0.5
R = 0.32549,0.513725,0.670588,0.5
BackgroundColor = 0.211765,0.321569,0.619608
GradientBackground = 0.2
CycleColors = false
Cycles = 1
EnableFloor = false Locked
FloorNormal = 0,0,1 Locked
FloorHeight = -1.1
FloorColor = 1,1,1
HF_Fallof = 2
HF_Const = 0
HF_Intensity = 1
HF_Dir = 0,0,1
HF_Offset = -0.3
HF_Color = 0.137255,0.168627,0.27451,1
HF_Scatter = 10
HF_Anisotropy = 0,0,0
HF_FogIter = 2
HF_CastShadow = true
HCloudScale = 1
HCloudFlatness = 0.7
HCloudTops = 4
HCloudBase = 1
HCloudDensity = 0.3
HCloudRoughness = 0.5
HCloudContrast = 10
HCloudColor = 1,1,1
HCloudWindDir = 0.5,0.5,0
HCloudWindSpeed = 1
mtime = -180
CloudScale = 0.72528
CloudFlatness = 0
CloudTops = 1
CloudBase = -4
CloudDensity = 0.7
CloudRoughness = 1.7
CloudContrast = 5
CloudColor = 0.501961,0.501961,0.501961
SunLightColor = 1,1,1
WindDir = 0,1,0
WindSpeed = 1
fRotX = 0
fRotY = 180
fRotZ = 130.867
fScaleX = 3
fScaleY = 3
fScaleZ = 3
fTwist = 0
fX = 0
fY = 0
fZ = -0.65
clipToBox = true Locked
showClippingBox = false Locked
boxRotAngle = 0
boxW = 5
boxH = 5
boxD = 5
boxX = 0
boxY = 0
boxZ = -4.8206
foldBoxSeparateAxes = false Locked
foldBoxStartIt = 256 Locked
foldBoxIts = 0 Locked
Trans = 1.584,0.5096,-0.3719
foldingLimitX = 0
foldingValueX = 2
foldingLimitY = 0
foldingValueY = 0
foldingLimitZ = 0
foldingValueZ = 0
rotVector = 0,1,0
rotAngle = 0
foldSphereStartIt = 256 Locked
foldSphereIts = 3 Locked
posW = 0
Scale = 0.74178
MinRad2 = 1.13636
Julia = 0,0,0
QTIterations = 12
QTThreshold = 16
QTC = 0.1,0.95,0.1,0
Up = -6.72315e-10,0.681641,0.731687
boxRotVector = 0,0,1
#endpreset

#preset #preset  BetweenTheClouds-Fog-Clouds-Sliced-BoxFold
FOV = 1.5
UseTrueFOV = true
TrueFOV = 75
UseFocalLength = false
FocalLength = 9.41347
FilmGate = 36
Eye = 0.3,-1.84887,1.64477
Ey_ = 0,-4.5,6.61604e-12
Target = 0.3,-0.239164,0.145157
Targe_ = 0,-3.5,0.75
FocalPlane = 2
Aperture = 0
InFocusAWidth = 0.5
ApertureNbrSides = 5
ApertureRot = 0
ApStarShaped = false
Gamma = 2
ToneMapping = 3
Exposure = 1
Brightness = 1
Contrast = 1
Saturation = 1
GaussianWeight = 1
AntiAliasScale = 2
Bloom = false
BloomIntensity = 0.25
BloomPow = 2
BloomTaps = 4
Detail = -3.5
DetailAO = -0.5
AutoFocus = true
FudgeFactor = 0.95
MaxRaySteps = 512
MaxDistance = 15
MaxRayStepsDiv = 10
Dither = 0.95
NormalBackStep = 5
AO = 0.0901961,0.4,0.494118,1
AoCorrect = 0
Specular = 0.4
SpecularExp = 8
SpecularMax = 16
SunLight = 1,0.976471,0.705882,1
SunDir = -0.5,-0.15
QualityShadows = true Locked
DebugSun = false
CamLight = 1,1,1,1
CamLightMin = 0.1
Glow = 1,1,1,0
GlowMax = 0
Fog = 0
FogExp = 0
Reflection = 0,0,0
ReflectionsNumber = 0
SpotGlow = true Locked
SpotLight = 1,1,1,2
SpotLightPos = 0,0,1.3068
LightSize = 0.05
LightFallOff = 0.2
LightGlowRad = 0.5
LightGlowExp = 1
HardShadow = 1
ShadowSoft = 15
BaseColor = 0.443137,0.443137,0.443137
OrbitStrength = 0.5
X = 0,0.666667,0.498039,0.5
Y = 0,0.666667,1,0.5
Z = 1,0,0.498039,0.5
R = 0.32549,0.513725,0.670588,0.5
BackgroundColor = 0.211765,0.321569,0.619608
GradientBackground = 0.2
CycleColors = false
Cycles = 1
EnableFloor = false Locked
FloorNormal = 0,0,1 Locked
FloorHeight = -1.1
FloorColor = 1,1,1
HF_Fallof = 2
HF_Const = 0
HF_Intensity = 1
HF_Dir = 0,0,1
HF_Offset = -0.3
HF_Color = 0.137255,0.168627,0.27451,1
HF_Scatter = 0
HF_Anisotropy = 0,0,0
HF_FogIter = 2
HF_CastShadow = false
HCloudScale = 1
HCloudFlatness = 0.7
HCloudTops = 4
HCloudBase = 1
HCloudDensity = 0.3
HCloudRoughness = 0.5
HCloudContrast = 10
HCloudColor = 1,1,1
HCloudWindDir = 0.5,0.5,0
HCloudWindSpeed = 1
mtime = -180
CloudScale = 1.3
CloudFlatness = 0.5
CloudTops = 2
CloudBase = -3
CloudDensity = 0.5
CloudRoughness = 1
CloudContrast = 2
CloudColor = 0.929412,0.976471,1
SunLightColor = 0.25098,0.392157,0.513725
WindDir = 0,1,0
WindSpeed = 1
fRotX = 0
fRotY = 180
fRotZ = 130.867
fScaleX = 3
fScaleY = 3
fScaleZ = 3
fTwist = 0
fX = 0
fY = 0
fZ = -0.65
clipToBox = true Locked
showClippingBox = false Locked
boxRotAngle = 0
boxW = 5
boxH = 5
boxD = 5
boxX = 0
boxY = 0
boxZ = -4.8206
foldBoxSeparateAxes = true Locked
foldBoxStartIt = 0 Locked
foldBoxIts = 5 Locked
Trans = 0,0.5096,0
foldingLimitX = 1.3
foldingValueX = 2
foldingLimitY = 2
foldingValueY = 2
foldingLimitZ = 2
foldingValueZ = 2
rotVector = 0,1,0
rotAngle = 0
foldSphereStartIt = 256 Locked
foldSphereIts = 3 Locked
posW = 0
Scale = 0.74178
MinRad2 = 1.13636
Julia = 0,0,0
QTIterations = 12
QTThreshold = 16
QTC = 0.1,0.95,0.7,0.15
Up = -6.72315e-10,0.681641,0.731687
boxRotVector = 0,0,1
#endpreset


#preset #preset  BetweenTheClouds-Fog-Clouds-BoxFold-SphereFold
FOV = 1.5
UseTrueFOV = true
TrueFOV = 75
UseFocalLength = false
FocalLength = 9.41347
FilmGate = 36
Eye = 0.3,-1.84887,1.64477
Ey_ = 0,-4.5,6.61604e-12
Target = 0.3,-0.239164,0.145157
Targe_ = 0,-3.5,0.75
FocalPlane = 2
Aperture = 0
InFocusAWidth = 0.5
ApertureNbrSides = 5
ApertureRot = 0
ApStarShaped = false
Gamma = 2
ToneMapping = 3
Exposure = 1
Brightness = 1
Contrast = 1
Saturation = 1
GaussianWeight = 1
AntiAliasScale = 2
Bloom = false
BloomIntensity = 0.25
BloomPow = 2
BloomTaps = 4
Detail = -3.5
DetailAO = -0.5
AutoFocus = true
FudgeFactor = 0.95
MaxRaySteps = 512
MaxDistance = 15
MaxRayStepsDiv = 10
Dither = 0.95
NormalBackStep = 5
AO = 0.0901961,0.4,0.494118,1
AoCorrect = 0
Specular = 0.4
SpecularExp = 8
SpecularMax = 16
SunLight = 1,0.976471,0.705882,1
SunDir = -0.5,-0.15
QualityShadows = true Locked
DebugSun = false
CamLight = 1,1,1,1
CamLightMin = 0.1
Glow = 1,1,1,0
GlowMax = 0
Fog = 0
FogExp = 0
Reflection = 0,0,0
ReflectionsNumber = 0
SpotGlow = true Locked
SpotLight = 1,1,1,2
SpotLightPos = 0,0,0.2272
LightSize = 0.22251
LightFallOff = 0.2
LightGlowRad = 0.6964
LightGlowExp = 1
HardShadow = 1
ShadowSoft = 15
BaseColor = 0.443137,0.443137,0.443137
OrbitStrength = 0.5
X = 0,0.666667,0.498039,0.5
Y = 0,0.666667,1,0.5
Z = 1,0,0.498039,0.5
R = 0.32549,0.513725,0.670588,0.5
BackgroundColor = 0.211765,0.321569,0.619608
GradientBackground = 0.2
CycleColors = false
Cycles = 1
EnableFloor = false Locked
FloorNormal = 0,0,1 Locked
FloorHeight = -1.1
FloorColor = 1,1,1
HF_Fallof = 2
HF_Const = 0.5
HF_Intensity = 1
HF_Dir = 0,0,1
HF_Offset = -0.3
HF_Color = 0.137255,0.168627,0.27451,1
HF_Scatter = 0
HF_Anisotropy = 0,0,0
HF_FogIter = 2
HF_CastShadow = false
HCloudScale = 1
HCloudFlatness = 0.7
HCloudTops = 4
HCloudBase = 1
HCloudDensity = 0.3
HCloudRoughness = 0.5
HCloudContrast = 10
HCloudColor = 1,1,1
HCloudWindDir = 0.5,0.5,0
HCloudWindSpeed = 1
mtime = -180
CloudScale = 1.3
CloudFlatness = 0.5
CloudTops = 2
CloudBase = -3
CloudDensity = 0.5
CloudRoughness = 1
CloudContrast = 2
CloudColor = 0.929412,0.976471,1
SunLightColor = 0.25098,0.392157,0.513725
WindDir = 0,1,0
WindSpeed = 1
fRotX = 0
fRotY = 180
fRotZ = 130.867
fScaleX = 1
fScaleY = 1
fScaleZ = 1
fTwist = 0
fX = 0
fY = 0
fZ = 0.9406
clipToBox = false Locked
showClippingBox = false Locked
boxRotAngle = 0
boxW = 5
boxH = 5
boxD = 5
boxX = 0
boxY = 0
boxZ = -4.8206
foldBoxSeparateAxes = true Locked
foldBoxStartIt = 0 Locked
foldBoxIts = 5 Locked
Trans = 0,0.5096,3.1218
foldingLimitX = 1.3
foldingValueX = 2
foldingLimitY = 2
foldingValueY = 2
foldingLimitZ = 2
foldingValueZ = 2
rotVector = 0,1,0
rotAngle = 0
foldSphereStartIt = 0 Locked
foldSphereIts = 4 Locked
posW = 0
Scale = 1
MinRad2 = 1.57702
Julia = 0.6642,1.4411,-0.0627
QTIterations = 12
QTThreshold = 16
QTC = 0.1,0.95,0.1,0
Up = -6.72315e-10,0.681641,0.731687
boxRotVector = 0,0,1
#endpreset


#preset #preset  BetweenTheClouds-Fog-Clouds-Volumetrics-Floor
FOV = 1.5
UseTrueFOV = true
TrueFOV = 75
UseFocalLength = false
FocalLength = 9.41347
FilmGate = 36
Eye = 1.1,-0.308154,0.60348
Ey_ = 0,-4.5,6.61604e-12
Target = 1.1,1.67282,-0.353454
Targe_ = 0,-3.5,0.75
FocalPlane = 2
Aperture = 0
InFocusAWidth = 0.5
ApertureNbrSides = 5
ApertureRot = 0
ApStarShaped = false
Gamma = 2
ToneMapping = 3
Exposure = 1
Brightness = 1
Contrast = 1
Saturation = 1
GaussianWeight = 1
AntiAliasScale = 2
Bloom = false
BloomIntensity = 0.25
BloomPow = 2
BloomTaps = 4
Detail = -3.2
DetailAO = -0.5
AutoFocus = true
FudgeFactor = 0.95
MaxRaySteps = 512
MaxDistance = 15
MaxRayStepsDiv = 10
Dither = 0.95
NormalBackStep = 5
AO = 0.0901961,0.4,0.494118,1
AoCorrect = 0
Specular = 0.4
SpecularExp = 8
SpecularMax = 16
SunLight = 1,0.976471,0.705882,1
SunDir = -0.5,-0.15
QualityShadows = true Locked
DebugSun = false
CamLight = 1,1,1,1
CamLightMin = 0.1
Glow = 1,1,1,0
GlowMax = 0
Fog = 0
FogExp = 0
Reflection = 0,0,0
ReflectionsNumber = 0
SpotGlow = true Locked
SpotLight = 1,1,1,2
SpotLightPos = 0,0,0.2272
LightSize = 0.22251
LightFallOff = 0.2
LightGlowRad = 0.6964
LightGlowExp = 1
HardShadow = 1
ShadowSoft = 15
BaseColor = 0.443137,0.443137,0.443137
OrbitStrength = 0.5
X = 0,0.666667,0.498039,0.5
Y = 0,0.666667,1,0.5
Z = 1,0,0.498039,0.5
R = 0.32549,0.513725,0.670588,0.5
BackgroundColor = 0.211765,0.321569,0.619608
GradientBackground = 0.2
CycleColors = false
Cycles = 1
EnableFloor = true Locked
FloorNormal = 0,0,1 Locked
FloorHeight = -0.25
FloorColor = 1,1,1
HF_Fallof = 2
HF_Const = 0
HF_Intensity = 0.42541
HF_Dir = 0,0,1
HF_Offset = 0.6044
HF_Color = 0.0862745,0.105882,0.176471,1
HF_Scatter = 10
HF_Anisotropy = 0,0,0
HF_FogIter = 2
HF_CastShadow = false
HCloudScale = 1
HCloudFlatness = 0.7
HCloudTops = 4
HCloudBase = 1
HCloudDensity = 0.3
HCloudRoughness = 0.5
HCloudContrast = 10
HCloudColor = 1,1,1
HCloudWindDir = 0.5,0.5,0
HCloudWindSpeed = 1
mtime = 0
CloudScale = 1
CloudFlatness = 0
CloudTops = 1
CloudBase = 0
CloudDensity = 0
CloudRoughness = 1
CloudContrast = 1
CloudColor = 0.929412,0.976471,1
SunLightColor = 0.25098,0.392157,0.513725
WindDir = 0,1,0
WindSpeed = 1
fRotX = 0
fRotY = 90
fRotZ = 90
fScaleX = 3
fScaleY = 3
fScaleZ = 3
fTwist = 0
fX = 0
fY = 0
fZ = 0.0496
clipToBox = false Locked
showClippingBox = false Locked
boxRotAngle = 0
boxW = 5
boxH = 5
boxD = 5
boxX = 0
boxY = 0
boxZ = 0
foldBoxSeparateAxes = false Locked
foldBoxStartIt = 256 Locked
foldBoxIts = 0 Locked
Trans = 0,0.5096,3.1218
foldingLimitX = 1.3
foldingValueX = 2
foldingLimitY = 2
foldingValueY = 2
foldingLimitZ = 2
foldingValueZ = 2
rotVector = 0,1,0
rotAngle = 0
foldSphereStartIt = 256 Locked
foldSphereIts = 0 Locked
posW = 0
Scale = 1
MinRad2 = 1.57702
Julia = 0.6642,1.4411,-0.0627
QTIterations = 12
QTThreshold = 16
QTC = 0.1,0.95,0.1,0
Up = 7.61872e-10,0.434971,0.900445
boxRotVector = 0,0,1
#endpreset

